var searchData=
[
  ['defined_5ffunc',['defined_func',['../plplotluacLUA__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aead6f867c497426f7186863e3851644f',1,'defined_func():&#160;plplotcPYTHON_wrap.c']]],
  ['delaunay',['delaunay',['../nn_8h.html#a79d7f711a971d206b6807d6c1d1c1dc2',1,'nn.h']]],
  ['dir',['DIR',['../dirent__msvc_8h.html#acd3a9d173749674d17dc5a5618f5e97a',1,'dirent_msvc.h']]],
  ['dirent',['dirent',['../dirent__msvc_8h.html#a789e4aa152d69b1205ea69ddb159c5b2',1,'dirent_msvc.h']]],
  ['drvoptcmd',['DrvOptCmd',['../plargs_8c.html#a9f5d22d9bb9fd5fa8fa4c5e047003797',1,'plargs.c']]]
];
